/*
 * XdccDownloader - ChannelTopic.java - Copyright © 2013 David Roden
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.pterodactylus.irc.event;

import net.pterodactylus.irc.Connection;

/**
 * Notifies a listener that a channel topic has been set.
 *
 * @author <a href="mailto:bombe@pterodactylus.net">David ‘Bombe’ Roden</a>
 */
public class ChannelTopic extends AbstractChannelEvent {

	/** The topic that has been set. */
	private final String topic;

	/**
	 * Creates a new channel topic event.
	 *
	 * @param connection
	 * 		The connection the event occured on
	 * @param channel
	 * 		The channel the topic was set on
	 * @param topic
	 * 		The topic that was set
	 */
	public ChannelTopic(Connection connection, String channel, String topic) {
		super(connection, channel);
		this.topic = topic;
	}

	//
	// ACCESSORS
	//

	/**
	 * Returns the topic that was set.
	 *
	 * @return The topic that was set
	 */
	public String topic() {
		return topic;
	}

}
