/*
 * XdccDownloader - StatsCommand.java - Copyright © 2013 David Roden
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.pterodactylus.xdcc.ui.stdin;

import static java.util.Collections.emptyList;

import java.io.IOException;
import java.io.Writer;
import java.util.Collection;
import java.util.List;
import java.util.Set;

import net.pterodactylus.xdcc.core.Core;
import net.pterodactylus.xdcc.data.Bot;
import net.pterodactylus.xdcc.data.Pack;

import com.google.common.collect.Sets;

/**
 * Command that outputs a short statistic of what is going on.
 *
 * @author <a href="mailto:bombe@pterodactylus.net">David ‘Bombe’ Roden</a>
 */
public class StatsCommand implements Command {

	/** The core to operate on. */
	private final Core core;

	/**
	 * Creates a new stats command.
	 *
	 * @param core
	 * 		The core to operate on
	 */
	public StatsCommand(Core core) {
		this.core = core;
	}

	//
	// COMMAND METHODS
	//

	@Override
	public String getName() {
		return "stats";
	}

	@Override
	public Collection<String> getAliases() {
		return emptyList();
	}

	@Override
	public State execute(State state, List<String> parameters, Writer outputWriter) throws IOException {
		int configuredChannelsCount = core.channels().size();
		int joinedChannelsCount = core.joinedChannels().size();
		int extraChannelsCount = core.extraChannels().size();
		Collection<Bot> bots = core.bots();
		Set<String> packNames = Sets.newHashSet();
		int packsCount = 0;
		for (Bot bot : bots) {
			packsCount += bot.packs().size();
			for (Pack pack : bot) {
				packNames.add(pack.name());
			}
		}

		outputWriter.write(String.format("%d channels (%d joined, %d extra), %d bots offering %d packs (%d unique).\n", configuredChannelsCount, joinedChannelsCount, extraChannelsCount, bots.size(), packsCount, packNames.size()));
		outputWriter.flush();
		return state;
	}

}
